==> mysql-connector-net-8.0.22-src.zip: EFCore/src/Query/Internal/MySQLQueryTranslationPostprocessor.cs <==
﻿// Copyright (c) 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

using Microsoft.EntityFrameworkCore.Query;
using MySql.Data.EntityFrameworkCore.Infrastructure.Internal;
using System.Linq.Expressions;

namespace MySql.Data.EntityFrameworkCore.Query.Internal
{
  internal class MySQLQueryTranslationPostprocessor : RelationalQueryTranslationPostprocessor
  {
    private readonly IMySQLOptions _options;

    public MySQLQueryTranslationPostprocessor(
        QueryTranslationPostprocessorDependencies dependencies,
        RelationalQueryTranslationPostprocessorDependencies relationalDependencies,
        QueryCompilationContext queryCompilationContext,
        IMySQLOptions options)
        : base(dependencies, relationalDependencies, queryCompilationContext)
    {
      _options = options;
    }

    public override Expression Process(Expression query)
    {
      query = base.Process(query);
      return new MySQLCompatibilityExpressionVisitor(_options).Visit(query);
    }
  }
}

==> mysql-connector-net-8.0.29-src.zip: EFCore/src/Query/Internal/MySQLQueryTranslationPostprocessor.cs <==
﻿// Copyright (c) 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

using Microsoft.EntityFrameworkCore.Query;
using MySql.EntityFrameworkCore.Infrastructure.Internal;
using System.Linq.Expressions;

namespace MySql.EntityFrameworkCore.Query.Internal
{
  internal class MySQLQueryTranslationPostprocessor : RelationalQueryTranslationPostprocessor
  {
    private readonly IMySQLOptions _options;

    public MySQLQueryTranslationPostprocessor(
        QueryTranslationPostprocessorDependencies dependencies,
        RelationalQueryTranslationPostprocessorDependencies relationalDependencies,
        QueryCompilationContext queryCompilationContext,
        IMySQLOptions options)
        : base(dependencies, relationalDependencies, queryCompilationContext)
    {
      _options = options;
    }

    public override Expression Process(Expression query)
    {
      query = base.Process(query);
      return new MySQLCompatibilityExpressionVisitor(_options).Visit(query);
    }
  }
}
